@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -103,9 +103,9 @@ class CertificateAuthority(proto.Message):
             Required. Immutable. The config used to
             create a self-signed X.509 certificate or CSR.
         lifetime (google.protobuf.duration_pb2.Duration):
-            Required. The desired lifetime of the CA certificate. Used
-            to create the "not_before_time" and "not_after_time" fields
-            inside an X.509 certificate.
+            Required. Immutable. The desired lifetime of the CA
+            certificate. Used to create the "not_before_time" and
+            "not_after_time" fields inside an X.509 certificate.
         key_spec (google.cloud.security.privateca_v1.types.CertificateAuthority.KeyVersionSpec):
             Required. Immutable. Used when issuing certificates for this
             [CertificateAuthority][google.cloud.security.privateca.v1.CertificateAuthority].
@@ -212,7 +212,7 @@ class CertificateAuthority(proto.Message):
         [CryptoKeyVersionAlgorithm][google.cloud.kms.v1.CryptoKeyVersion.CryptoKeyVersionAlgorithm]
         values. For RSA signing algorithms, the PSS algorithms should be
         preferred, use PKCS1 algorithms if required for compatibility. For
-        further recommandations, see
+        further recommendations, see
         https://cloud.google.com/kms/docs/algorithms#algorithm_recommendations.
         """
         SIGN_HASH_ALGORITHM_UNSPECIFIED = 0
@@ -251,6 +251,13 @@ class CertificateAuthority(proto.Message):
         [CertificateAuthority][google.cloud.security.privateca.v1.CertificateAuthority]
         will use.
 
+        This message has `oneof`_ fields (mutually exclusive fields).
+        For each oneof, at most one member field can be set at the same time.
+        Setting any member of the oneof automatically clears all other
+        members.
+
+        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
         Attributes:
             cloud_kms_key_version (str):
                 The resource name for an existing Cloud KMS CryptoKeyVersion
@@ -258,12 +265,16 @@ class CertificateAuthority(proto.Message):
                 ``projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*``.
                 This option enables full flexibility in the key's
                 capabilities and properties.
+
+                This field is a member of `oneof`_ ``KeyVersion``.
             algorithm (google.cloud.security.privateca_v1.types.CertificateAuthority.SignHashAlgorithm):
                 The algorithm to use for creating a managed Cloud KMS key
                 for a for a simplified experience. All managed keys will be
                 have their
                 [ProtectionLevel][google.cloud.kms.v1.ProtectionLevel] as
                 ``HSM``.
+
+                This field is a member of `oneof`_ ``KeyVersion``.
         """
 
         cloud_kms_key_version = proto.Field(proto.STRING, number=1, oneof="KeyVersion",)
@@ -464,12 +475,23 @@ class CaPool(proto.Message):
             may refer to either a fully-qualified key algorithm, such as RSA
             4096, or a family of key algorithms, such as any RSA key.
 
+            This message has `oneof`_ fields (mutually exclusive fields).
+            For each oneof, at most one member field can be set at the same time.
+            Setting any member of the oneof automatically clears all other
+            members.
+
+            .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
             Attributes:
                 rsa (google.cloud.security.privateca_v1.types.CaPool.IssuancePolicy.AllowedKeyType.RsaKeyType):
                     Represents an allowed RSA key type.
+
+                    This field is a member of `oneof`_ ``key_type``.
                 elliptic_curve (google.cloud.security.privateca_v1.types.CaPool.IssuancePolicy.AllowedKeyType.EcKeyType):
                     Represents an allowed Elliptic Curve key
                     type.
+
+                    This field is a member of `oneof`_ ``key_type``.
             """
 
             class RsaKeyType(proto.Message):
@@ -480,14 +502,14 @@ class CaPool(proto.Message):
                 Attributes:
                     min_modulus_size (int):
                         Optional. The minimum allowed RSA modulus
-                        size, in bits. If this is not set, or if set to
-                        zero, the service-level min RSA modulus size
-                        will continue to apply.
+                        size (inclusive), in bits. If this is not set,
+                        or if set to zero, the service-level min RSA
+                        modulus size will continue to apply.
                     max_modulus_size (int):
                         Optional. The maximum allowed RSA modulus
-                        size, in bits. If this is not set, or if set to
-                        zero, the service will not enforce an explicit
-                        upper bound on RSA modulus sizes.
+                        size (inclusive), in bits. If this is not set,
+                        or if set to zero, the service will not enforce
+                        an explicit upper bound on RSA modulus sizes.
                 """
 
                 min_modulus_size = proto.Field(proto.INT64, number=1,)
@@ -681,6 +703,13 @@ class Certificate(proto.Message):
     corresponds to a signed X.509 certificate issued by a
     [CertificateAuthority][google.cloud.security.privateca.v1.CertificateAuthority].
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         name (str):
             Output only. The resource name for this
@@ -690,9 +719,13 @@ class Certificate(proto.Message):
         pem_csr (str):
             Immutable. A pem-encoded X.509 certificate
             signing request (CSR).
+
+            This field is a member of `oneof`_ ``certificate_config``.
         config (google.cloud.security.privateca_v1.types.CertificateConfig):
             Immutable. A description of the certificate
             and key that does not require X.509 or ASN.1.
+
+            This field is a member of `oneof`_ ``certificate_config``.
         issuer_certificate_authority (str):
             Output only. The resource name of the issuing
             [CertificateAuthority][google.cloud.security.privateca.v1.CertificateAuthority]
@@ -904,12 +937,15 @@ class X509Parameters(proto.Message):
 
     class CaOptions(proto.Message):
         r"""Describes values that are relevant in a CA certificate.
+
         Attributes:
             is_ca (bool):
                 Optional. Refers to the "CA" X.509 extension,
                 which is a boolean value. When this value is
                 missing, the extension will be omitted from the
                 CA certificate.
+
+                This field is a member of `oneof`_ ``_is_ca``.
             max_issuer_path_length (int):
                 Optional. Refers to the path length
                 restriction X.509 extension. For a CA
@@ -918,6 +954,8 @@ class X509Parameters(proto.Message):
                 If this value is less than 0, the request will
                 fail. If this value is missing, the max path
                 length will be omitted from the CA certificate.
+
+                This field is a member of `oneof`_ ``_max_issuer_path_length``.
         """
 
         is_ca = proto.Field(proto.BOOL, number=1, optional=True,)
@@ -938,20 +976,31 @@ class SubordinateConfig(proto.Message):
     [CertificateAuthority][google.cloud.security.privateca.v1.CertificateAuthority],
     or a PEM issuer certificate chain.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         certificate_authority (str):
             Required. This can refer to a
             [CertificateAuthority][google.cloud.security.privateca.v1.CertificateAuthority]
-            in the same project that was used to create a subordinate
+            that was used to create a subordinate
             [CertificateAuthority][google.cloud.security.privateca.v1.CertificateAuthority].
             This field is used for information and usability purposes
             only. The resource name is in the format
             ``projects/*/locations/*/caPools/*/certificateAuthorities/*``.
+
+            This field is a member of `oneof`_ ``subordinate_config``.
         pem_issuer_chain (google.cloud.security.privateca_v1.types.SubordinateConfig.SubordinateConfigChain):
             Required. Contains the PEM certificate chain for the issuers
             of this
             [CertificateAuthority][google.cloud.security.privateca.v1.CertificateAuthority],
             but not pem certificate for this CA itself.
+
+            This field is a member of `oneof`_ ``subordinate_config``.
     """
 
     class SubordinateConfigChain(proto.Message):
@@ -1141,6 +1190,7 @@ class CertificateDescription(proto.Message):
 
     class CertificateFingerprint(proto.Message):
         r"""A group of fingerprints for the x509 certificate.
+
         Attributes:
             sha256_hash (str):
                 The SHA 256 hash, encoded in hexadecimal, of
@@ -1266,13 +1316,13 @@ class KeyUsage(proto.Message):
             server_auth (bool):
                 Corresponds to OID 1.3.6.1.5.5.7.3.1.
                 Officially described as "TLS WWW server
-                authentication", though regularly used for non-
-                WWW TLS.
+                authentication", though regularly used for
+                non-WWW TLS.
             client_auth (bool):
                 Corresponds to OID 1.3.6.1.5.5.7.3.2.
                 Officially described as "TLS WWW client
-                authentication", though regularly used for non-
-                WWW TLS.
+                authentication", though regularly used for
+                non-WWW TLS.
             code_signing (bool):
                 Corresponds to OID 1.3.6.1.5.5.7.3.3.
                 Officially described as "Signing of downloadable
@@ -1360,8 +1410,9 @@ class SubjectAltNames(proto.Message):
             Contains only valid 32-bit IPv4 addresses or
             RFC 4291 IPv6 addresses.
         custom_sans (Sequence[google.cloud.security.privateca_v1.types.X509Extension]):
-            Contains additional subject alternative name
-            values.
+            Contains additional subject alternative name values. For
+            each custom_san, the ``value`` field must contain an ASN.1
+            encoded UTF8String.
     """
 
     dns_names = proto.RepeatedField(proto.STRING, number=1,)
@@ -1384,8 +1435,7 @@ class CertificateIdentityConstraints(proto.Message):
             Subject Alternative Name before a certificate is
             signed. To see the full allowed syntax and some
             examples, see
-            https://cloud.google.com/certificate-authority-
-            service/docs/using-cel
+            https://cloud.google.com/certificate-authority-service/docs/using-cel
         allow_subject_passthrough (bool):
             Required. If this is true, the
             [Subject][google.cloud.security.privateca.v1.Subject] field
@@ -1393,6 +1443,8 @@ class CertificateIdentityConstraints(proto.Message):
             certificate. Otherwise, the requested
             [Subject][google.cloud.security.privateca.v1.Subject] will
             be discarded.
+
+            This field is a member of `oneof`_ ``_allow_subject_passthrough``.
         allow_subject_alt_names_passthrough (bool):
             Required. If this is true, the
             [SubjectAltNames][google.cloud.security.privateca.v1.SubjectAltNames]
@@ -1400,6 +1452,8 @@ class CertificateIdentityConstraints(proto.Message):
             signed certificate. Otherwise, the requested
             [SubjectAltNames][google.cloud.security.privateca.v1.SubjectAltNames]
             will be discarded.
+
+            This field is a member of `oneof`_ ``_allow_subject_alt_names_passthrough``.
     """
 
     cel_expression = proto.Field(proto.MESSAGE, number=1, message=expr_pb2.Expr,)
