@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -252,6 +252,13 @@ class CertificateAuthority(proto.Message):
         [CertificateAuthority][google.cloud.security.privateca.v1beta1.CertificateAuthority]
         if they violate the policy.
 
+        This message has `oneof`_ fields (mutually exclusive fields).
+        For each oneof, at most one member field can be set at the same time.
+        Setting any member of the oneof automatically clears all other
+        members.
+
+        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
         Attributes:
             allowed_config_list (google.cloud.security.privateca_v1beta1.types.CertificateAuthority.CertificateAuthorityPolicy.AllowedConfigList):
                 Optional. All
@@ -261,6 +268,8 @@ class CertificateAuthority(proto.Message):
                 must match at least one listed
                 [ReusableConfigWrapper][google.cloud.security.privateca.v1beta1.ReusableConfigWrapper]
                 in the list.
+
+                This field is a member of `oneof`_ ``config_policy``.
             overwrite_config_values (google.cloud.security.privateca_v1beta1.types.ReusableConfigWrapper):
                 Optional. All
                 [Certificates][google.cloud.security.privateca.v1beta1.Certificate]
@@ -268,6 +277,8 @@ class CertificateAuthority(proto.Message):
                 [CertificateAuthority][google.cloud.security.privateca.v1beta1.CertificateAuthority]
                 will use the provided configuration values, overwriting any
                 requested configuration values.
+
+                This field is a member of `oneof`_ ``config_policy``.
             allowed_locations_and_organizations (Sequence[google.cloud.security.privateca_v1beta1.types.Subject]):
                 Optional. If any
                 [Subject][google.cloud.security.privateca.v1beta1.Subject]
@@ -319,6 +330,7 @@ class CertificateAuthority(proto.Message):
 
         class AllowedConfigList(proto.Message):
             r"""
+
             Attributes:
                 allowed_config_values (Sequence[google.cloud.security.privateca_v1beta1.types.ReusableConfigWrapper]):
                     Required. All
@@ -350,12 +362,12 @@ class CertificateAuthority(proto.Message):
                 allowed_dns_names (Sequence[str]):
                     Optional. Contains valid, fully-qualified host names. Glob
                     patterns are also supported. To allow an explicit wildcard
-                    certificate, escape with backlash (i.e. "*"). E.g. for
-                    globbed entries: '*bar.com' will allow foo.bar.com, but not
-                    *.bar.com, unless the
+                    certificate, escape with backlash (i.e. ``\*``). E.g. for
+                    globbed entries: ``*bar.com`` will allow ``foo.bar.com``,
+                    but not ``*.bar.com``, unless the
                     [allow_globbing_dns_wildcards][google.cloud.security.privateca.v1beta1.CertificateAuthority.CertificateAuthorityPolicy.AllowedSubjectAltNames.allow_globbing_dns_wildcards]
-                    field is set. E.g. for wildcard entries: '*.bar.com' will
-                    allow '*.bar.com', but not 'foo.bar.com'.
+                    field is set. E.g. for wildcard entries: ``\*.bar.com`` will
+                    allow ``*.bar.com``, but not ``foo.bar.com``.
                 allowed_uris (Sequence[str]):
                     Optional. Contains valid RFC 3986 URIs. Glob patterns are
                     also supported. To match across path seperators (i.e. '/')
@@ -465,6 +477,13 @@ class CertificateAuthority(proto.Message):
         [CertificateAuthority][google.cloud.security.privateca.v1beta1.CertificateAuthority]
         will use.
 
+        This message has `oneof`_ fields (mutually exclusive fields).
+        For each oneof, at most one member field can be set at the same time.
+        Setting any member of the oneof automatically clears all other
+        members.
+
+        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
         Attributes:
             cloud_kms_key_version (str):
                 Required. The resource name for an existing Cloud KMS
@@ -472,12 +491,16 @@ class CertificateAuthority(proto.Message):
                 ``projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*``.
                 This option enables full flexibility in the key's
                 capabilities and properties.
+
+                This field is a member of `oneof`_ ``KeyVersion``.
             algorithm (google.cloud.security.privateca_v1beta1.types.CertificateAuthority.SignHashAlgorithm):
                 Required. The algorithm to use for creating a managed Cloud
                 KMS key for a for a simplified experience. All managed keys
                 will be have their
                 [ProtectionLevel][google.cloud.kms.v1.ProtectionLevel] as
                 ``HSM``.
+
+                This field is a member of `oneof`_ ``KeyVersion``.
         """
 
         cloud_kms_key_version = proto.Field(proto.STRING, number=1, oneof="KeyVersion",)
@@ -610,6 +633,13 @@ class Certificate(proto.Message):
     corresponds to a signed X.509 certificate issued by a
     [CertificateAuthority][google.cloud.security.privateca.v1beta1.CertificateAuthority].
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         name (str):
             Output only. The resource path for this
@@ -619,9 +649,13 @@ class Certificate(proto.Message):
         pem_csr (str):
             Immutable. A pem-encoded X.509 certificate
             signing request (CSR).
+
+            This field is a member of `oneof`_ ``certificate_config``.
         config (google.cloud.security.privateca_v1beta1.types.CertificateConfig):
             Immutable. A description of the certificate
             and key that does not require X.509 or ASN.1.
+
+            This field is a member of `oneof`_ ``certificate_config``.
         lifetime (google.protobuf.duration_pb2.Duration):
             Required. Immutable. The desired lifetime of a certificate.
             Used to create the "not_before_time" and "not_after_time"
@@ -770,6 +804,7 @@ class ReusableConfigValues(proto.Message):
 
     class CaOptions(proto.Message):
         r"""Describes values that are relevant in a CA certificate.
+
         Attributes:
             is_ca (google.protobuf.wrappers_pb2.BoolValue):
                 Optional. Refers to the "CA" X.509 extension,
@@ -806,14 +841,25 @@ class ReusableConfigWrapper(proto.Message):
     describes values that may assist in creating an X.509 certificate,
     or a reference to a pre-defined set of values.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         reusable_config (str):
             Required. A resource path to a
             [ReusableConfig][google.cloud.security.privateca.v1beta1.ReusableConfig]
             in the format ``projects/*/locations/*/reusableConfigs/*``.
+
+            This field is a member of `oneof`_ ``config_values``.
         reusable_config_values (google.cloud.security.privateca_v1beta1.types.ReusableConfigValues):
             Required. A user-specified inline
             [ReusableConfigValues][google.cloud.security.privateca.v1beta1.ReusableConfigValues].
+
+            This field is a member of `oneof`_ ``config_values``.
     """
 
     reusable_config = proto.Field(proto.STRING, number=1, oneof="config_values",)
@@ -828,6 +874,13 @@ class SubordinateConfig(proto.Message):
     [CertificateAuthority][google.cloud.security.privateca.v1beta1.CertificateAuthority],
     or a PEM issuer certificate chain.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         certificate_authority (str):
             Required. This can refer to a
@@ -837,11 +890,15 @@ class SubordinateConfig(proto.Message):
             This field is used for information and usability purposes
             only. The resource name is in the format
             ``projects/*/locations/*/certificateAuthorities/*``.
+
+            This field is a member of `oneof`_ ``subordinate_config``.
         pem_issuer_chain (google.cloud.security.privateca_v1beta1.types.SubordinateConfig.SubordinateConfigChain):
             Required. Contains the PEM certificate chain for the issuers
             of this
             [CertificateAuthority][google.cloud.security.privateca.v1beta1.CertificateAuthority],
             but not pem certificate for this CA itself.
+
+            This field is a member of `oneof`_ ``subordinate_config``.
     """
 
     class SubordinateConfigChain(proto.Message):
@@ -1038,6 +1095,7 @@ class CertificateDescription(proto.Message):
 
     class CertificateFingerprint(proto.Message):
         r"""A group of fingerprints for the x509 certificate.
+
         Attributes:
             sha256_hash (str):
                 The SHA 256 hash, encoded in hexadecimal, of
@@ -1166,13 +1224,13 @@ class KeyUsage(proto.Message):
             server_auth (bool):
                 Corresponds to OID 1.3.6.1.5.5.7.3.1.
                 Officially described as "TLS WWW server
-                authentication", though regularly used for non-
-                WWW TLS.
+                authentication", though regularly used for
+                non-WWW TLS.
             client_auth (bool):
                 Corresponds to OID 1.3.6.1.5.5.7.3.2.
                 Officially described as "TLS WWW client
-                authentication", though regularly used for non-
-                WWW TLS.
+                authentication", though regularly used for
+                non-WWW TLS.
             code_signing (bool):
                 Corresponds to OID 1.3.6.1.5.5.7.3.3.
                 Officially described as "Signing of downloadable
